@@ -1,9 +1,11 @@
 from .path import reset, workspace, add
 
-from .utl import today, now, yesterday, xprint, pretty
+from .utl import *
 
-from .wprint import *
+from .print import *
 
 from .log import *
 
-from .time import *
\ No newline at end of file
+from .time import *
+
+from .code import *
\ No newline at end of file
